@@ -257,7 +257,7 @@ class TestTranslatorEndToEnd(TestCase):
         'api_with_apikey_default_override',
         'api_with_apikey_required',
         'api_with_path_parameters',
-        'function_with_batch_window'
+        'function_with_event_source_mapping'
       ],
       [
        ("aws", "ap-southeast-1"),
